@@ -22,6 +22,8 @@ if (typeof Jemplate == 'undefined') {
     };
 }
 
+Jemplate.VERSION = '0.22';
+
 Jemplate.process = function() {
     var jemplate = new Jemplate();
     return jemplate.process.apply(jemplate, arguments);
@@ -1289,7 +1291,7 @@ Jemplate.Ajax = {
 
     processGet: function(url, processor) {
         this.get(url, function(responseText){
-            process(Jemplate.JSON.parse(responseText));
+            processor(Jemplate.JSON.parse(responseText));
         });
     },
 
